#
# spec file for package python-frozenlist
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-frozenlist
Version:        1.5.0
Release:        1.1
Summary:        Python list-like structure which implements MutableSequence
License:        Apache-2.0
URL:            https://github.com/aio-libs/frozenlist
Source:         https://files.pythonhosted.org/packages/source/f/frozenlist/frozenlist-%{version}.tar.gz
Patch1:         no-pytest-cov.patch
# PATCH-FIX-OPENSUSE - avoid embedding random tmp dir in .so
Patch2:         reproducible.patch
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module devel >= 3.8}
BuildRequires:  %{python_module expandvars}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%python_subpackages

%description
Python list-like structure which implements collections.abc.MutableSequence.

%prep
%autosetup -p1 -n frozenlist-%{version}

%build
export CFLAGS="%{optflags}"
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%pytest_arch

%files %{python_files}
%doc CHANGES.rst README.rst
%license LICENSE
%{python_sitearch}/frozenlist
%{python_sitearch}/frozenlist-%{version}*-info

%changelog
* Tue Oct 29 2024 Dirk Müller <dmueller@suse.com>
- update to 1.5.0:
  * An incorrect signature of the __class_getitem__ class method
    has been fixed, adding a missing class_item argument under
    Python 3.8 and older. This change also improves the code
    coverage of this method that was previously missing -- by
    :user:`webknjaz`. Related issues and pull requests on GitHub:
    :issue:`567`, :issue:`571`.
  * Rendered issue, PR, and commit links now lead to frozenlist's
    repo instead of yarl's repo. Related issues and pull requests
    on GitHub: :issue:`573`.
  * On the :doc:`Contributing docs <contributing/guidelines>`
    page, a link to the Towncrier philosophy has been fixed.
    Related issues and pull requests on GitHub: :issue:`574`.
  * A name of a temporary building directory now reflects that
    it's related to frozenlist, not yarl. Related issues and pull
    requests on GitHub: :issue:`573`.
  * Declared Python 3.13 supported officially in the distribution
    package metadata. Related issues and pull requests on GitHub:
    :issue:`595`.
- drop skip-some-attributes.patch (upstream)
* Mon Jul 29 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Cherry-pick patch from Fedora to fix testsuite with Python 3.13
  * skip-some-attributes.patch
* Tue Jan 16 2024 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to avoid embedding a random tmp dir (boo#1062303)
* Mon Jan  8 2024 Dirk Müller <dmueller@suse.com>
- update to 1.4.1:
  * Declared Python 3.12 and PyPy 3.8-3.10 supported officially
    in the distribution package metadata.
  * Replaced the packaging is replaced from an old-fashioned
    :file:`setup.py` to an in-tree PEP 517 build backend -- by
    :user:`webknjaz`. Whenever the end-users or downstream
    packagers need to build frozenlist from source (a Git
    checkout or an sdist), they may pass a config_settings flag
    pure-python. If this flag is not set, a C-extension will be
    built and included into the distribution. Here is how this
    can be done with pip:  $ python3 -m pip install . --config-
    settings=pure-python=  This will also work with -e |
  - -editable. The same can be achieved via pypa/build:  $
    python3 -m build --config-setting=pure-python=  Adding -w |
  - -wheel can force pypa/build produce a wheel from source
    directly, as opposed to building an sdist and then building
    from it. Related issues and pull requests on GitHub:
    :issue:`560`.
  * Replaced the packaging is replaced from an old-fashioned
    :file:`setup.py` to an in-tree PEP 517 build backend
  * Whenever the end-users or downstream packagers need to build
    frozenlist from source (a Git checkout or an sdist), they may
    pass a config_settings flag pure-python. If this flag is not
    set, a C-extension will be built and included into the
    distribution.
  * It is now possible to request line tracing in Cython builds
    using the with-cython-tracing PEP 517 config setting
  * This can be used in CI and development environment to measure
    coverage on Cython modules, but is not normally useful to the
    end-users or downstream packagers.
    Otherwise, it's off unless requested explicitly.
  * The following produces C-files required for the Cython
    coverage plugin to map the measurements back to the PYX-
    files:
  * Alternatively, the FROZENLIST_CYTHON_TRACING=1 environment
    variable can be set to do the same as the PEP 517 config
    setting.
  * Coverage collection has been implemented for the Cython
    modules
- add no-pytest-cov.patch to skip pytest-coverage
* Mon Aug 14 2023 Dirk Müller <dmueller@suse.com>
- update to 1.4.0:
  * The published source distribution package became buildable
  * under Python 3.12.
  * Removed an unused :py:data:`typing.Tuple` import
  * Deprecations and Removals
  * Dropped Python 3.7 support.
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Fri Dec  2 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 1.3.3
  * Fixed CI runs when creating a new release, where new towncrier versions fail
    when the current version section is already present.
- Update to 1.3.2
  * Misc
    Updated the CI runs to better check for test results and to avoid
    deprecated syntax. #327
* Wed Sep 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- update to 1.3.1
  * The published source distribution package became buildable under Python 3.11.
* Sun Jan 23 2022 Dirk Müller <dmueller@suse.com>
- update to 1.3.0:
  * Do not install C sources with binary distributions.
  * Dropped Python 3.6 support
* Sat Dec 11 2021 Ben Greiner <code@bnavigator.de>
- Update to 1.2.0
  * FrozenList now supports being used as a generic type as per PEP
    585, e.g. frozen_int_list: FrozenList[int] (requires Python 3.9
    or newer). #172
  * Added support for Python 3.10. #227
  * Started shipping platform-specific wheels with the musl tag
    targeting typical Alpine Linux runtimes. #227
  * Started shipping platform-specific arm64 wheels for Apple
    Silicon. #227
- Cythonize
- Required by some aio packages.
* Sun Nov 29 2020 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v1.1.1
